==> open-xchange-core_7.6.0.orig.tar.bz2: open-xchange-core-7.6.0/com.openexchange.quota/src/com/openexchange/quota/QuotaService.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2020 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.quota;

import com.openexchange.exception.OXException;
import com.openexchange.session.Session;

/**
 * {@link QuotaService} - The quota service.
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public interface QuotaService {

    /**
     * Gets the quota for denoted resource that needs no {@link ResourceDescription resource description}.
     * <p>
     * <b>Note</b>: In order to query possible quota restriction, an appropriate {@link QuotaRestriction} needs to be registered for desired
     * {@link Resource resource}.
     * <p>
     * Pre-Defined resources are:
     * <ul>
     * <li>{@link Resource#CALENDAR}</li>
     * <li>{@link Resource#CONTACT}</li>
     * <li>{@link Resource#TASK}</li>
     * <li>{@link Resource#INFOSTORE_FILES}</li>
     * <ul>
     * <p>
     *
     * @param resource The resource
     * @param session The user session
     * @return The quota
     * @throws OXException If querying quota fails
     */
    Quota getQuotaFor(Resource resource, Session session) throws OXException;

    /**
     * Gets the quota for denoted resource.
     * <p>
     * <b>Note</b>: In order to query possible quota restriction, an appropriate {@link QuotaRestriction} needs to be registered for desired
     * {@link Resource resource}.
     * <p>
     * Pre-Defined resources are:
     * <ul>
     * <li>{@link Resource#CALENDAR}</li>
     * <li>{@link Resource#CONTACT}</li>
     * <li>{@link Resource#TASK}</li>
     * <li>{@link Resource#INFOSTORE_FILES}</li>
     * <ul>
     * <p>
     *
     * @param resource The resource
     * @param desc The resource description (if needed to determine resource's quota); or
     *            {@link ResourceDescription#getEmptyResourceDescription()} if none needed
     * @param session The user session
     * @return The quota
     * @throws OXException If querying quota fails
     * @see ResourceDescription#getEmptyResourceDescription()
     */
    Quota getQuotaFor(Resource resource, ResourceDescription desc, Session session) throws OXException;
}

==> open-xchange-core_7.6.1.orig.tar.bz2: open-xchange-core-7.6.1/com.openexchange.quota/src/com/openexchange/quota/QuotaService.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2020 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.quota;

import java.util.List;

/**
 * Open-Xchange consists of a set of modules that serve user requests.
 * Every module that allows users to store data may provide limits for a
 * certain amount of storage and a certain number of items that it will handle
 * for each user. In other words, every module can have user-specific quotas
 * for storage size and items. Those quotas may be set by definition or
 * by configuration and can also be unlimited. The responsibility to
 * enforce quotas lies within the modules themselves, but they can announce
 * their quotas via this service. That enables a client to provide a
 * combined overview over all quotas. Each module that wants to contribute
 * to this service has to implement a {@link QuotaProvider}.
 *
 * @author <a href="mailto:steffen.templin@open-xchange.com">Steffen Templin</a>
 * @since v7.6.1
 */
public interface QuotaService {

    /**
     * Gets all currently known {@link QuotaProvider}s.
     *
     * @return A list of providers. Never <code>null</code> but possibly empty.
     */
    List<QuotaProvider> getAllProviders();

    /**
     * Gets the provider for a specific module, if available.
     *
     * @param moduleID The modules unique identifier.
     * @return The modules provider or <code>null</code>, if unknown.
     */
    QuotaProvider getProvider(String moduleID);

}
